/**
 * Copyright Openmind http://www.openmindonline.it
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package net.sourceforge.openutils.mgnlmessages.i18n;

import info.magnolia.cms.i18n.AbstractMessagesImpl;
import info.magnolia.cms.i18n.Messages;
import info.magnolia.module.ModuleRegistry;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Set;


/**
 * @author molaschi
 * @version $Id: $
 */
public class ModulePropertyMessagesImpl extends AbstractMessagesImpl
{

    List<Messages> messages = new ArrayList<Messages>();

    /**
     * @param basename
     * @param locale
     */
    @SuppressWarnings("unchecked")
    public ModulePropertyMessagesImpl(Locale locale)
    {
        super("", locale);
        ModuleRegistry reg = ModuleRegistry.Factory.getInstance();
        for (String name : (Set<String>) reg.getModuleNames())
        {
            messages.add(new SimpleMessagesImpl("mgnl-messages." + name + ".messages", locale));
        }
    }

    /**
     * {@inheritDoc}
     */
    public String get(String key)
    {
        String value;
        for (Messages m : messages)
        {
            value = m.get(key);
            if (value != null)
            {
                return value;
            }
        }
        if (key == null)
        {
            return "??????";
        }
        return "???" + key + "???";
    }

    /**
     * {@inheritDoc}
     */
    @SuppressWarnings("unchecked")
    public Iterator keys()
    {
        List<String> keys = new ArrayList<String>();
        for (Messages m : messages)
        {
            Iterator it = m.keys();
            while (it.hasNext())
            {
                keys.add((String) it.next());
            }
        }
        return keys.iterator();
    }

    /**
     * {@inheritDoc}
     */
    public void reload() throws Exception
    {
        for (Messages m : messages)
        {
            m.reload();
        }
    }

}
